@@ -58,12 +58,11 @@ class CustomerProfile(AuthorizenetProfileBase):
         """A list of the customer's payment profile ids, if any."""
         try:
             response = self._authorizenet_get_customer_profile(issuer_info=False)
-            print(f"{response = }")
             return [
                 int(profile.customerPaymentProfileId)
                 for profile in response.profile.paymentProfiles
             ]
-        except ControllerExecutionError:
+        except (ControllerExecutionError, AttributeError):
             return []
 
     @property
@@ -71,20 +70,13 @@ class CustomerProfile(AuthorizenetProfileBase):
         """A list of the customer's address profile ids, if any."""
         try:
             response = self._authorizenet_get_customer_profile(issuer_info=False)
-            print(f"{response = }")
             return [
                 int(profile.customerAddressId)
                 for profile in response.profile.shipToList
             ]
-        except ControllerExecutionError:
+        except (ControllerExecutionError, AttributeError):
             return []
 
-    @property
-    def exists(self) -> bool:
-        """Whether or not the customer profile exists in Authorizenet."""
-        profile_ids = get_customer_profile_ids()
-        return int(self.id) in profile_ids if self.id is not None else False
-
     def _authorizenet_get_customer_profile_ids(self) -> dict | None:
         """
         Executes a :py:obj:`~authorizenet.apicontractsv1.getCustomerProfileIdsRequest` using the Authorizenet API.
